package service

import (
	"encoding/json"
	"errors"
	"f5"
	"main/mt"
	"q5"
)

var gamesGoods   q5.ConcurrentMap[int64, map[int64]GoodsInfo] //[gameid, [goodsid]goodsinfo]
type serviceMgr struct {	
}

func (this *serviceMgr) Init() {
	gamesGoods = q5.ConcurrentMap[int64, map[int64]GoodsInfo]{}

	Wxpay.init()
	Redis.init()
	Hwpay.init()

	mt.Table.Wxconfig.Traverse(func(w *mt.Wxconfig) bool {
		filename := "../res/gamegoods/" + q5.SafeToString(w.GetGameid()) + ".json"
		str, err := f5.ReadJsonFile(filename)
		if err != nil {
			return true
		}
		data := []map[string]interface{}{}
		if json.Unmarshal([]byte(str), &data) != nil {
			f5.GetSysLog().Error("parse [%s] error.", filename)
		} else {
			gamegoods := map[int64]GoodsInfo{}
			for _, data := range data {
				gamegoods[q5.SafeToInt64(data["id"])] = GoodsInfo{
					Name:  q5.SafeToString(data["name"]),
					Count: q5.SafeToInt64(data["count"]),
					Price: q5.SafeToInt64(data["price"]) * 100,
				}
			}
			gamesGoods.Store(w.GetGameid(), gamegoods)
		}
		return true
	})
}

func (this *serviceMgr) UnInit() {
	Wxpay.unInit()
	Redis.unInit()
	Hwpay.unInit()
}

func GetGoodsCount(gameid int64, goodsid int64) (count int64, err error) {
	goods, ok := gamesGoods.Load(gameid)
	if !ok {
		return 0, errors.New("no game")
	}

	info, ok := (*goods)[goodsid]
	if !ok {
		return 0, errors.New("no goods")
	}

	return info.Count, nil
}

func GetGoodsName(gameid int64, goodsid int64) (name string, err error) {
	goods, ok := gamesGoods.Load(gameid)
	if !ok {
		return "", errors.New("no game")
	}

	info, ok := (*goods)[goodsid]
	if !ok {
		return "", errors.New("no goods")
	}

	return info.Name, nil
}